#
# spec file for package kgraphviewer
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           kgraphviewer
Version:        24.12.3
Release:        1.1
Summary:        Graphviz dot graph file viewer
License:        GPL-2.0-only
URL:            https://apps.kde.org/kgraphviewer
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  boost-devel
BuildRequires:  graphviz-devel >= 2.30
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6Parts) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Requires:       graphviz

%description
KGraphViewer is a Graphviz dot graph file viewer, aimed to replace the other
outdated Graphviz tools. Graphs are commonly used in scientific domains and
particularly in computer science.

%package -n libkgraphviewer0
Summary:        Graphviz dot graph file viewer

%description -n libkgraphviewer0
KGraphViewer is a Graphviz dot graph file viewer, aimed to replace the other
outdated Graphviz tools. Graphs are commonly used in scientific domains and
particularly in computer science.

This package install the kgraphviewer library.

%package -n kgraphviewer-devel
Summary:        Development files for kgraphviewer
Requires:       kgraphviewer = %{version}
Requires:       libkgraphviewer0 = %{version}

%description -n kgraphviewer-devel
Development files for kgraphviewer.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang kgraphviewer --with-html kgraphviewer.lang

%ldconfig_scriptlets -n libkgraphviewer0

%files
%license COPYING COPYING.DOC
%doc AUTHORS
%doc %lang(en) %{_kf6_htmldir}/en/kgraphviewer
%{_kf6_applicationsdir}/org.kde.kgraphviewer.desktop
%{_kf6_appstreamdir}/org.kde.kgraphviewer.appdata.xml
%{_kf6_bindir}/kgraphviewer
%{_kf6_configkcfgdir}/kgraphviewer_partsettings.kcfg
%{_kf6_configkcfgdir}/kgraphviewersettings.kcfg
%{_kf6_debugdir}/kgraphviewer.categories
%{_kf6_iconsdir}/hicolor/*/apps/kgraphviewer.png
%{_kf6_plugindir}/kf6/parts/kgraphviewerpart.so

%files -n libkgraphviewer0
%{_kf6_libdir}/libkgraphviewer.so.*

%files -n kgraphviewer-devel
%{_includedir}/kgraphviewer/
%{_kf6_cmakedir}/KGraphViewerPart/
%{_kf6_libdir}/libkgraphviewer.so

%files lang -f kgraphviewer.lang
%exclude %{_kf6_htmldir}/en/kgraphviewer

%changelog
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- No code change since 24.12.2
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- No code change since 24.08.3
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- kgraphviewer is now released with KDE gear applications
* Thu May  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 2.5.0:
  https://blogs.kde.org/2024/05/08/kgraphviewer-2.5.0-released/
  * Port to Qt6 and KF6
  * General code modernization
* Fri Dec 15 2023 Christophe Marin <christophe@krop.fr>
- Require extra-cmake-modules at build time
* Wed Jul 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Use _kf5_debugdir for logging categories files.
- Run spec-cleaner
* Mon Sep 17 2018 wbauer@tmo.at
- Update to 2.4.3
  * https://jriddell.org/2018/09/17/kgraphviewer-2-4-3/
  * Switch KgvPageLayout to QPageSize for page size handling
  * Avoid double top-level layout in KGVSimplePrintingPageSetup
  * Fix layout of page layout & size dialog
  * Remove unused dependency KIO
  * Fix minor typo
  * Update kgraphviewer docbook
  * Make sure the Graphviz library directories are known to the linker
* Wed Sep 27 2017 wbauer@tmo.at
- Update to 2.4.2
  * http://jriddell.org/2017/09/27/kgraphviewer-2-4-2/
  * add missing find dependency macro
  * Fix broken reloading and broken layout changing due to lost filename
  * kgraphviewer_part.rc: set fallback text for toplevel menu entries
  * desktop-mime-but-no-exec-code
  * Codefix, comparisons were meant to be assignments
  * KGraphViewer 2.4.1 was made with an incorrect internal version number
    and should be ignored
* Tue Sep 12 2017 wbauer@tmo.at
- Update to 2.4.0
  * http://jriddell.org/2017/09/12/kgraphviewer-2-4-0/
- Drop old_graphviz.diff, 13.1 and lower are no longer supported
* Sun Nov 30 2014 hrvoje.senjan@gmail.com
- Update to 2.2 final
  * For more details, please see
    http://milianw.de/blog/massif-visualizer-04-and-kgraphviewer-22-released
* Wed Nov 12 2014 cgiboudeaux@gmx.com
- Add KGraphViewer 2.2Beta
- Drop the _service file
* Mon Oct 14 2013 cgiboudeaux@gmx.com
- Update translations
* Sun Mar  6 2011 cgiboudeaux@gmail.com
- Update snapshot (git-20110306)
* Wed Dec 15 2010 cgiboudeaux@gmail.com
- Update snapshot (git-20101215)
  - ------------------------------------------------------------------
* Tue Dec 14 2010 cgiboudeaux@gmail.com
- Update snapshot (git-20101214)
  - ------------------------------------------------------------------
* Sat Dec 11 2010 cgiboudeaux@gmail.com
- Update snapshot (git-20101211)
  - ------------------------------------------------------------------
* Tue Nov 30 2010 cgiboudeaux@gmail.com
- Update snapshot (git-20101130)
  - ------------------------------------------------------------------
* Sat Nov 27 2010 cgiboudeaux@gmail.com
- Update snapshot (git-20101127)
  - ------------------------------------------------------------------
* Wed Nov 17 2010 cgiboudeaux@gmail.com
- Update snapshot (git-20101117)
  - ------------------------------------------------------------------
* Sun Nov 14 2010 cgiboudeaux@gmail.com
- Update snapshot (git-20101114)
  - ------------------------------------------------------------------
* Mon Sep 20 2010 cgiboudeaux@gmail.com
- Kgraphviewer 2.0.90 (svn)
